$(function () {
	var csInterface = new CSInterface(); 
	
	// Update the color of the panel when the theme color of the product changed.
	updateThemeWithAppSkinInfo(csInterface.hostEnvironment.appSkinInfo);

    // Listen for color theme change.
	csInterface.addEventListener(CSInterface.THEME_COLOR_CHANGED_EVENT, onAppThemeColorChanged);
	
    // Listen for Update Preferences.
	csInterface.addEventListener("com.adobe.csxs.events.illustratorimpactui.UpdatePreferences", updatePreferences);

    // Listen for Update Working Directory.
	csInterface.addEventListener("com.adobe.csxs.events.illustratorimpactui.UpdatePreferencesWorkingDirectory", updateWorkingDirectory);

    // Listen for change to the preference resize artboard checkbox.
	$("#PrefResizeArtboardCB").change(prefResizeArtboardChange);
	
    // Listen for OK button click.
	$("#PrefOkButton").click(prefOKButtonClick);
	
    // Listen for Cancel button click.
	$("#PrefCancelButton").click(prefCancelButtonClick);

    // Listen for Choose working dir button click.
    $("#PrefWorkingDirChooseBtn").click(prefWorkingDirChooseBtnClick);
	
	csInterface.setWindowTitle("Impact CAD Preferences");

	var preferencesReadyEvent = new CSEvent('com.adobe.csxs.events.illustratorimpactui.PreferencesReady', 'APPLICATION', 'ILST', 'com.ardensoftware.illustratorimpactui.preferences');
	csInterface.dispatchEvent(preferencesReadyEvent);	
});

/// <summary>
/// Update the preference panel with values from the dictionary and the values saved in the preferences.
/// </summary>
function updatePreferences(event) {
    var xmlData = $.parseXML(event.data);

    var $xml = $(xmlData);
		
    var neverPrompt = $xml.find('neverPrompt').text();
    var templateLayers = $xml.find('templateLayers').text();
    var resizeArtboard = $xml.find('resizeArtboard').text();
    var resizeArtboardMatchText = $xml.find('resizeArtboardMatchText').text();
    var autoConnect = $xml.find('autoConnect').text();
    var exportMTSText = $xml.find('exportMTSText').text();
    var workingDirText = $xml.find('workingDirText').text();
    var needsLiveLinkPrefsText = $xml.find('needsLiveLinkPrefs').text();

    var fileProcessingLabel = $xml.find('fileProcessingLabel').text();
    $("#PrefFileProcessingLabel").text(fileProcessingLabel);
    var neverPromptLabel = $xml.find('neverPromptLabel').text();
    $("#PrefNeverPromptLabel").text(neverPromptLabel);
    var templateLayersLabel = $xml.find('templateLayersLabel').text();
    $("#PrefTemplateLayersLabel").text(templateLayersLabel);
    var resizeArtboardLabel = $xml.find('resizeArtboardLabel').text();
    $("#PrefResizeArtboardLabel").text(resizeArtboardLabel);
    var resizeArtboardMatchLabel = $xml.find('resizeArtboardMatchLabel').text();
    $("#PrefResizeArtboardMatchTextLabel").text(resizeArtboardMatchLabel);
    var okButtonLabel = $xml.find('okButtonLabel').text();
    $("#PrefOkButton").text(okButtonLabel);
    var cancelButtonLabel = $xml.find('cancelButtonLabel').text();
    $("#PrefCancelButton").text(cancelButtonLabel);
    var exportMTSLabel = $xml.find('exportMTSLabel').text();
    $("#PrefLiveLinkExportMTSLabel").text(exportMTSLabel);
    var liveLinkLabel = $xml.find('liveLinkLabel').text();
    $("#PrefLiveLinkLabel").text(liveLinkLabel);
    var autoConnectLabel = $xml.find('autoConnectLabel').text();
    $("#PrefLiveLinkAutoConnectLabel").text(autoConnectLabel);
    var workingDirLabel = $xml.find('workingDirLabel').text();
    $("#PrefWorkingDirLabel").text(workingDirLabel);
    var workingDirChooseLabel = $xml.find('workingDirChooseLabel').text();
    $("#PrefWorkingDirChooseBtn").text(workingDirChooseLabel);

    if (neverPrompt == 'true')
        $("#PrefNeverPromptCB").prop('checked', true);
    else
        $("#PrefNeverPromptCB").prop('checked', false);
		
    if (templateLayers == 'true')
        $("#PrefTemplateLayersCB").prop('checked', true);
    else
        $("#PrefTemplateLayersCB").prop('checked', false);
		
    $("#PrefResizeArtboardMatchText").val(resizeArtboardMatchText);
		
    if (resizeArtboard == 'true') {
        $("#PrefResizeArtboardCB").prop('checked', true);
        $("#PrefResizeArtboardMatchText").prop('disabled', false);
    }
    else {
        $("#PrefResizeArtboardCB").prop('checked', false);
        $("#PrefResizeArtboardMatchText").prop('disabled', true);
    }

    if (autoConnect == 'true')
        $("#PrefLiveLinkAutoConnectCB").prop('checked', true);
    else
        $("#PrefLiveLinkAutoConnectCB").prop('checked', false);

    $("#PrefLiveLinkExportMTSText").val(exportMTSText);
    
    $("#PrefWorkingDirText").text(workingDirText);

    if (needsLiveLinkPrefsText == 'false')
        $("#PrefLiveLinkSettingsWrapper").remove();

    var windowTitle = $xml.find('windowTitle').text();
    new CSInterface().setWindowTitle(windowTitle);
}

/// <summary>
/// Disable the text edit for resizing the artboard when the checkbox is unchecked.
/// </summary>
function prefResizeArtboardChange(event) {
    if ($("#PrefResizeArtboardCB").is(':checked')) {
        $("#PrefResizeArtboardMatchText").prop('disabled', false);
    }
    else {
        $("#PrefResizeArtboardMatchText").prop('disabled', true);
    }
}

/// <summary>
/// Saves preferences and closes window.
/// </summary>
function prefOKButtonClick(event) {	
    var preferencesOkEvent = new CSEvent('com.adobe.csxs.events.illustratorimpactui.PreferencesOkClick', 'APPLICATION', 'ILST', 'com.ardensoftware.illustratorimpactui.preferences');
		
    var neverPrompt = $("#PrefNeverPromptCB").is(':checked');
    var templateLayers = $("#PrefTemplateLayersCB").is(':checked');
    var resizeArtboard = $("#PrefResizeArtboardCB").is(':checked');
    var resizeArtboardString = $("#PrefResizeArtboardMatchText").val();
    var autoConnect = $("#PrefLiveLinkAutoConnectCB").is(':checked');
    var exportMTSString = $("#PrefLiveLinkExportMTSText").val();
    var workingDirString = $("#PrefWorkingDirText").text();
    var data = '<payload><neverPrompt>'+neverPrompt+'</neverPrompt><templateLayers>'+
        templateLayers+'</templateLayers><resizeArtboard>'+resizeArtboard+'</resizeArtboard><resizeArtboardMatchText>'+
        resizeArtboardString + '</resizeArtboardMatchText><autoConnect>' + autoConnect + '</autoConnect><exportMTSText>' +
        exportMTSString + '</exportMTSText><workingDirText>' + workingDirString + '</workingDirText></payload>';
		
    preferencesOkEvent.data = data;
		
    var csInterface = new CSInterface();
    csInterface.dispatchEvent(preferencesOkEvent);
		
    csInterface.closeExtension();
}

/// <summary>
/// Closes window.
/// </summary>
function prefCancelButtonClick(event) {	
    new CSInterface().closeExtension();
}

/// <summary>
/// Opens working directory choose dialog.
/// </summary>
function prefWorkingDirChooseBtnClick(event) {
    var preferencesWorkingDirChooseEvent = new CSEvent('com.adobe.csxs.events.illustratorimpactui.WorkingDirChooseClick', 'APPLICATION', 'ILST', 'com.ardensoftware.illustratorimpactui.preferences');

    new CSInterface().dispatchEvent(preferencesWorkingDirChooseEvent);
}

/// <summary>
/// Update the working directory text.
/// </summary>
function updateWorkingDirectory(event) {
    var xmlData = $.parseXML(event.data);

    var $xml = $(xmlData);

    var workingDirText = $xml.find('workingDirText').text();

    $("#PrefWorkingDirText").text(workingDirText);
}